@@ -34,10 +34,10 @@ class Presenter:
     Animation = namedtuple("Animation", ["delay", "duration", "element"])
 
     @staticmethod
-    def build_presenter(folder, /, *args, ensemble=[], strict=True, roles=1):
+    def build_presenter(folder, /, *args, ensemble=[], strict=True, roles=1, **kwargs):
         for n, p in enumerate(folder.paths):
             folder_dialogue = Drama.load_dialogue(folder.pkg, p)
-            text = Drama.write_dialogue(folder_dialogue, *args)
+            text = Drama.write_dialogue(folder_dialogue, *args, **kwargs)
             rv = Presenter.build_from_text(text, ensemble=ensemble, strict=strict, roles=roles, path=p)
             if rv:
                 return (n, rv)
@@ -51,7 +51,7 @@ class Presenter:
         if all(selection.values()) or (not strict and any(selection.values())):
             script.cast(selection)
             model = script.run()
-            rv = Presenter(model, ensemble=ensemble)
+            rv = Presenter(model, ensemble=ensemble, text=text)
             for k, v in model.metadata:
                 rv.metadata[k].append(v)
             return rv
@@ -65,7 +65,7 @@ class Presenter:
             fmt = "".join(("{0.", item.attr, "}"))
             try:
                 lhs = fmt.format(item.object)
-            except (AttributeError, IndexError, KeyError, ValueError):
+            except (AttributeError, IndexError, KeyError, TypeError, ValueError):
                 return False
             else:
                 rhs = str(item.val)
@@ -113,7 +113,7 @@ class Presenter:
                 continue
         return rv
 
-    def __init__(self, dialogue, scene=None, ensemble=None):
+    def __init__(self, dialogue, scene=None, ensemble=None, text=""):
         self.frames = [
             defaultdict(list, dict(
                 {k: list(v) for k, v in itertools.groupby(i.items, key=type)},
@@ -124,6 +124,7 @@ class Presenter:
         ]
         self.ensemble = ensemble
         self.metadata = defaultdict(list)
+        self.text = text
 
     @property
     def dwell(self) -> float:
