@@ -17,6 +17,7 @@ import functools
 import re
 import textwrap
 
+from turberfield.catchphrase.drama import Drama
 from turberfield.catchphrase.presenter import Presenter
 from turberfield.dialogue.model import Model
 from turberfield.dialogue.types import DataObject
@@ -24,8 +25,6 @@ from turberfield.dialogue.types import DataObject
 """
 catchphrase-banner
     A region of decorative text and background images. Style multiple `catchphrase-banner`s with CSS `nth-of-type`.
-catchphrase-widget catchphrase-widget-<class>
-    An instance of `catchphrase.widget.Widget`.
 catchphrase-reveal
     A region animated to progressively reveal the contents (may include images, icons, etc)
 catchphrase-colour-shadows
@@ -59,9 +58,15 @@ preload="auto" {'loop="loop"' if anim.element.loop and int(anim.element.loop) >
     def animated_line_to_html(anim):
         name = anim.element.persona.name if hasattr(anim.element.persona, "name") else ""
         name = "{0.firstname} {0.surname}".format(name) if hasattr(name, "firstname") else name
+        if getattr(anim.element.persona, "history", []):  # As per Drama
+            tag = '<blockquote class="catchphrase-method-{0}">'.format(
+                anim.element.persona.history[-1].fn.__name__.lower()
+            )
+        else:
+            tag = "<blockquote>"
         return f"""
 <li style="animation-delay: {anim.delay:.2f}s; animation-duration: {anim.duration:.2f}s">
-<blockquote>
+{tag}
 <header>{name}</header>
 {anim.element.html}
 </blockquote>
@@ -183,16 +188,6 @@ pattern="{validator.pattern}"
             if i.element.text:
                 yield (Renderer.animated_line_to_terminal(i), i.duration)
 
-    @staticmethod
-    def render_frame_to_text(frame, ensemble=[], title="", final=False):
-        return "\n".join(
-            ["{0}{1}{2}".format(
-                " ".join(filter(None, anim.element.persona.name)) if hasattr(anim.element.persona, "name") else "",
-                ": " if hasattr(anim.element.persona, "name") else "",
-                anim.element.text
-            ) for anim in frame[Model.Line]]
-        )
-
     @staticmethod
     def render_dict_to_css(mapping=None, tag=":root"):
         mapping = mapping or {}
